@@ -4,6 +4,9 @@
 
 #pragma once
 
+#include "RNA_access.hh"
+#include "RNA_blender_cpp.hh"
+
 #include "scene/mesh.h"
 #include "scene/scene.h"
 
@@ -14,16 +17,32 @@
 #include "util/transform.h"
 #include "util/types.h"
 
-#include "RNA_blender_cpp.hh"
-
 #include "DNA_mesh_types.h"
+#include "DNA_object_types.h"
+#include "DNA_view3d_types.h"
 
+#include "BKE_global.hh"
 #include "BKE_image.hh"
+#include "BKE_lib_id.hh"
 #include "BKE_mesh.h"
 #include "BKE_mesh_types.hh"
+#include "BKE_mesh_wrapper.hh"
 
 CCL_NAMESPACE_BEGIN
 
+static inline BL::ID object_get_data(const BL::Object &b_ob, const bool use_adaptive_subdivision)
+{
+  ::Object *object = reinterpret_cast<::Object *>(b_ob.ptr.data);
+
+  if (!use_adaptive_subdivision && object->type == OB_MESH) {
+    ::Mesh *mesh = static_cast<::Mesh *>(object->data);
+    mesh = BKE_mesh_wrapper_ensure_subdivision(mesh);
+    return BL::ID(RNA_id_pointer_create(&mesh->id));
+  }
+
+  return BL::ID(RNA_id_pointer_create(reinterpret_cast<ID *>(object->data)));
+}
+
 struct BObjectInfo {
   /* Object directly provided by the depsgraph iterator. This object is only valid during one
    * iteration and must not be accessed afterwards. Transforms and visibility should be checked on
@@ -35,52 +54,44 @@ struct BObjectInfo {
   BL::Object real_object;
 
   /* The object-data referenced by the iter object. This is still valid after the depsgraph
-   * iterator is done. It might have a different type compared to real_object.data(). */
+   * iterator is done. It might have a different type compared to object_get_data(real_object). */
   BL::ID object_data;
 
+  /* Object will use adaptive subdivision. */
+  bool use_adaptive_subdivision;
+
   /* True when the current geometry is the data of the referenced object. False when it is a
    * geometry instance that does not have a 1-to-1 relationship with an object. */
   bool is_real_object_data() const
   {
-    return const_cast<BL::Object &>(real_object).data() == object_data;
+    return object_get_data(const_cast<BL::Object &>(real_object), use_adaptive_subdivision) ==
+           object_data;
   }
 };
 
+static inline BL::Mesh object_copy_mesh_data(const BObjectInfo &b_ob_info)
+{
+  ::Object *object = static_cast<::Object *>(b_ob_info.real_object.ptr.data);
+  ::Mesh *mesh = BKE_mesh_new_from_object(
+      nullptr, object, false, false, !b_ob_info.use_adaptive_subdivision);
+  return BL::Mesh(RNA_id_pointer_create(&mesh->id));
+}
+
 using BlenderAttributeType = BL::ShaderNodeAttribute::attribute_type_enum;
 BlenderAttributeType blender_attribute_name_split_type(ustring name, string *r_real_name);
 
 void python_thread_state_save(void **python_thread_state);
 void python_thread_state_restore(void **python_thread_state);
 
-static bool mesh_use_corner_normals(BL::Mesh &mesh, Mesh::SubdivisionType subdivision_type)
+static bool mesh_use_corner_normals(const BObjectInfo &b_ob_info, BL::Mesh &mesh)
 {
-  return mesh && (subdivision_type == Mesh::SUBDIVISION_NONE) &&
+  return mesh && !b_ob_info.use_adaptive_subdivision &&
          (static_cast<const ::Mesh *>(mesh.ptr.data)->normals_domain(true) ==
           blender::bke::MeshNormalDomain::Corner);
 }
 
-static inline BL::Mesh object_to_mesh(BL::BlendData & /*data*/,
-                                      BObjectInfo &b_ob_info,
-                                      BL::Depsgraph & /*depsgraph*/,
-                                      bool /*calc_undeformed*/,
-                                      Mesh::SubdivisionType subdivision_type)
+static inline BL::Mesh object_to_mesh(BObjectInfo &b_ob_info)
 {
-  /* TODO: make this work with copy-on-evaluation, modifiers are already evaluated. */
-#if 0
-  bool subsurf_mod_show_render = false;
-  bool subsurf_mod_show_viewport = false;
-
-  if (subdivision_type != Mesh::SUBDIVISION_NONE) {
-    BL::Modifier subsurf_mod = object.modifiers[object.modifiers.length() - 1];
-
-    subsurf_mod_show_render = subsurf_mod.show_render();
-    subsurf_mod_show_viewport = subsurf_mod.show_viewport();
-
-    subsurf_mod.show_render(false);
-    subsurf_mod.show_viewport(false);
-  }
-#endif
-
   BL::Mesh mesh = (b_ob_info.object_data.is_a(&RNA_Mesh)) ? BL::Mesh(b_ob_info.object_data) :
                                                             BL::Mesh(PointerRNA_NULL);
 
@@ -90,43 +101,31 @@ static inline BL::Mesh object_to_mesh(BL::BlendData & /*data*/,
     if (mesh) {
       if (mesh.is_editmode()) {
         /* Flush edit-mesh to mesh, including all data layers. */
-        BL::Depsgraph depsgraph(PointerRNA_NULL);
-        mesh = b_ob_info.real_object.to_mesh(false, depsgraph);
-        use_corner_normals = mesh_use_corner_normals(mesh, subdivision_type);
+        mesh = object_copy_mesh_data(b_ob_info);
+        use_corner_normals = mesh_use_corner_normals(b_ob_info, mesh);
       }
-      else if (mesh_use_corner_normals(mesh, subdivision_type)) {
+      else if (mesh_use_corner_normals(b_ob_info, mesh)) {
         /* Make a copy to split faces. */
-        BL::Depsgraph depsgraph(PointerRNA_NULL);
-        mesh = b_ob_info.real_object.to_mesh(false, depsgraph);
+        mesh = object_copy_mesh_data(b_ob_info);
         use_corner_normals = true;
       }
     }
     else {
-      BL::Depsgraph depsgraph(PointerRNA_NULL);
-      mesh = b_ob_info.real_object.to_mesh(false, depsgraph);
-      use_corner_normals = mesh_use_corner_normals(mesh, subdivision_type);
+      mesh = object_copy_mesh_data(b_ob_info);
+      use_corner_normals = mesh_use_corner_normals(b_ob_info, mesh);
     }
   }
   else {
     /* TODO: what to do about non-mesh geometry instances? */
-    use_corner_normals = mesh_use_corner_normals(mesh, subdivision_type);
+    use_corner_normals = mesh_use_corner_normals(b_ob_info, mesh);
   }
 
-#if 0
-  if (subdivision_type != Mesh::SUBDIVISION_NONE) {
-    BL::Modifier subsurf_mod = object.modifiers[object.modifiers.length() - 1];
-
-    subsurf_mod.show_render(subsurf_mod_show_render);
-    subsurf_mod.show_viewport(subsurf_mod_show_viewport);
-  }
-#endif
-
   if (mesh) {
     if (use_corner_normals) {
       mesh.split_faces();
     }
 
-    if (subdivision_type == Mesh::SUBDIVISION_NONE) {
+    if (b_ob_info.use_adaptive_subdivision) {
       mesh.calc_loop_triangles();
     }
   }
@@ -134,17 +133,15 @@ static inline BL::Mesh object_to_mesh(BL::BlendData & /*data*/,
   return mesh;
 }
 
-static inline void free_object_to_mesh(BL::BlendData & /*data*/,
-                                       BObjectInfo &b_ob_info,
-                                       BL::Mesh &mesh)
+static inline void free_object_to_mesh(BObjectInfo &b_ob_info, BL::Mesh &mesh)
 {
   if (!b_ob_info.is_real_object_data()) {
     return;
   }
   /* Free mesh if we didn't just use the existing one. */
   BL::Object object = b_ob_info.real_object;
-  if (object.data().ptr.data != mesh.ptr.data) {
-    object.to_mesh_clear();
+  if (object_get_data(object, b_ob_info.use_adaptive_subdivision).ptr.data != mesh.ptr.data) {
+    BKE_id_free(nullptr, static_cast<ID *>(mesh.ptr.data));
   }
 }
 
@@ -675,13 +672,11 @@ static inline BL::MeshSequenceCacheModifier object_mesh_cache_find(BL::Object &b
   return BL::MeshSequenceCacheModifier(PointerRNA_NULL);
 }
 
-static inline Mesh::SubdivisionType object_subdivision_type(BL::Object &b_ob,
-                                                            bool preview,
-                                                            bool experimental)
+static BL::SubsurfModifier object_subdivision_modifier(BL::Object &b_ob, const bool preview)
 {
   PointerRNA cobj = RNA_pointer_get(&b_ob.ptr, "cycles");
 
-  if (cobj.data && !b_ob.modifiers.empty() && experimental) {
+  if (cobj.data && !b_ob.modifiers.empty()) {
     BL::Modifier mod = b_ob.modifiers[b_ob.modifiers.length() - 1];
     const bool enabled = preview ? mod.show_viewport() : mod.show_render();
 
@@ -689,27 +684,98 @@ static inline Mesh::SubdivisionType object_subdivision_type(BL::Object &b_ob,
         RNA_boolean_get(&cobj, "use_adaptive_subdivision"))
     {
       BL::SubsurfModifier subsurf(mod);
-
-      if (subsurf.subdivision_type() == BL::SubsurfModifier::subdivision_type_CATMULL_CLARK) {
-        return Mesh::SUBDIVISION_CATMULL_CLARK;
-      }
-      return Mesh::SUBDIVISION_LINEAR;
+      return subsurf;
     }
   }
 
+  return PointerRNA_NULL;
+}
+
+static inline Mesh::SubdivisionType object_subdivision_type(BL::Object &b_ob,
+                                                            const bool preview,
+                                                            const bool use_adaptive_subdivision)
+{
+  if (!use_adaptive_subdivision) {
+    return Mesh::SUBDIVISION_NONE;
+  }
+
+  BL::SubsurfModifier subsurf = object_subdivision_modifier(b_ob, preview);
+
+  if (subsurf) {
+    if (subsurf.subdivision_type() == BL::SubsurfModifier::subdivision_type_CATMULL_CLARK) {
+      return Mesh::SUBDIVISION_CATMULL_CLARK;
+    }
+    return Mesh::SUBDIVISION_LINEAR;
+  }
+
   return Mesh::SUBDIVISION_NONE;
 }
 
+static inline void object_subdivision_to_mesh(BL::Object &b_ob,
+                                              Mesh &mesh,
+                                              const bool preview,
+                                              const bool use_adaptive_subdivision)
+{
+  if (!use_adaptive_subdivision) {
+    mesh.set_subdivision_type(Mesh::SUBDIVISION_NONE);
+    return;
+  }
+
+  BL::SubsurfModifier subsurf = object_subdivision_modifier(b_ob, preview);
+
+  if (!subsurf) {
+    mesh.set_subdivision_type(Mesh::SUBDIVISION_NONE);
+    return;
+  }
+
+  if (subsurf.subdivision_type() != BL::SubsurfModifier::subdivision_type_CATMULL_CLARK) {
+    mesh.set_subdivision_type(Mesh::SUBDIVISION_LINEAR);
+    return;
+  }
+
+  mesh.set_subdivision_type(Mesh::SUBDIVISION_CATMULL_CLARK);
+
+  switch (subsurf.boundary_smooth()) {
+    case BL::SubsurfModifier::boundary_smooth_PRESERVE_CORNERS:
+      mesh.set_subdivision_boundary_interpolation(Mesh::SUBDIVISION_BOUNDARY_EDGE_AND_CORNER);
+      break;
+    case BL::SubsurfModifier::boundary_smooth_ALL:
+      mesh.set_subdivision_boundary_interpolation(Mesh::SUBDIVISION_BOUNDARY_EDGE_ONLY);
+      break;
+  }
+
+  switch (subsurf.uv_smooth()) {
+    case BL::SubsurfModifier::uv_smooth_NONE:
+      mesh.set_subdivision_fvar_interpolation(Mesh::SUBDIVISION_FVAR_LINEAR_ALL);
+      break;
+    case BL::SubsurfModifier::uv_smooth_PRESERVE_CORNERS:
+      mesh.set_subdivision_fvar_interpolation(Mesh::SUBDIVISION_FVAR_LINEAR_CORNERS_ONLY);
+      break;
+    case BL::SubsurfModifier::uv_smooth_PRESERVE_CORNERS_AND_JUNCTIONS:
+      mesh.set_subdivision_fvar_interpolation(Mesh::SUBDIVISION_FVAR_LINEAR_CORNERS_PLUS1);
+      break;
+    case BL::SubsurfModifier::uv_smooth_PRESERVE_CORNERS_JUNCTIONS_AND_CONCAVE:
+      mesh.set_subdivision_fvar_interpolation(Mesh::SUBDIVISION_FVAR_LINEAR_CORNERS_PLUS2);
+      break;
+    case BL::SubsurfModifier::uv_smooth_PRESERVE_BOUNDARIES:
+      mesh.set_subdivision_fvar_interpolation(Mesh::SUBDIVISION_FVAR_LINEAR_BOUNDARIES);
+      break;
+    case BL::SubsurfModifier::uv_smooth_SMOOTH_ALL:
+      mesh.set_subdivision_fvar_interpolation(Mesh::SUBDIVISION_FVAR_LINEAR_NONE);
+      break;
+  }
+}
+
 static inline uint object_ray_visibility(BL::Object &b_ob)
 {
   uint flag = 0;
 
-  flag |= b_ob.visible_camera() ? PATH_RAY_CAMERA : 0;
-  flag |= b_ob.visible_diffuse() ? PATH_RAY_DIFFUSE : 0;
-  flag |= b_ob.visible_glossy() ? PATH_RAY_GLOSSY : 0;
-  flag |= b_ob.visible_transmission() ? PATH_RAY_TRANSMIT : 0;
-  flag |= b_ob.visible_shadow() ? PATH_RAY_SHADOW : 0;
-  flag |= b_ob.visible_volume_scatter() ? PATH_RAY_VOLUME_SCATTER : 0;
+  flag |= b_ob.visible_camera() ? PATH_RAY_CAMERA : PathRayFlag(0);
+  flag |= b_ob.visible_diffuse() ? PATH_RAY_DIFFUSE : PathRayFlag(0);
+  flag |= b_ob.visible_glossy() ? PATH_RAY_GLOSSY : PathRayFlag(0);
+  flag |= b_ob.visible_transmission() ? PATH_RAY_TRANSMIT : PathRayFlag(0);
+  flag |= b_ob.visible_shadow() ? PATH_RAY_SHADOW : PathRayFlag(0);
+  flag |= b_ob.visible_volume_scatter() ? PATH_RAY_VOLUME_SCATTER : PathRayFlag(0);
 
   return flag;
 }
@@ -748,6 +814,13 @@ static inline bool object_need_motion_attribute(BObjectInfo &b_ob_info, Scene *s
   return true;
 }
 
+static inline bool region_view3d_navigating_or_transforming(const BL::RegionView3D &b_rv3d)
+{
+  ::RegionView3D *rv3d = static_cast<::RegionView3D *>(b_rv3d.ptr.data);
+  return rv3d && ((rv3d->rflag & (RV3D_NAVIGATING | RV3D_PAINTING)) ||
+                  (G.moving & (G_TRANSFORM_OBJ | G_TRANSFORM_EDIT)));
+}
+
 class EdgeMap {
  public:
   EdgeMap() = default;
