@@ -1,5 +1,6 @@
-/* SPDX-License-Identifier: Apache-2.0
- * Copyright 2011-2022 Blender Foundation */
+/* SPDX-FileCopyrightText: 2011-2022 Blender Foundation
+ *
+ * SPDX-License-Identifier: Apache-2.0 */
 
 /* Constant Globals */
 
@@ -8,23 +9,30 @@
 #include "kernel/types.h"
 
 #include "kernel/integrator/state.h"
+#include "kernel/util/profiler.h"
 
-#include "kernel/util/profiling.h"
+#include "util/color.h"
+#include "util/texture.h"
 
 CCL_NAMESPACE_BEGIN
 
-/* Not actually used, just a NULL pointer that gets passed everywhere, which we
+/* Not actually used, just a nullptr pointer that gets passed everywhere, which we
  * hope gets optimized out by the compiler. */
 struct KernelGlobalsGPU {
   int unused[1];
 };
-typedef ccl_global const KernelGlobalsGPU *ccl_restrict KernelGlobals;
+using KernelGlobals = const ccl_global KernelGlobalsGPU *ccl_restrict;
 
 /* Launch parameters */
 struct KernelParamsOptiX {
   /* Kernel arguments */
   const int *path_index_array;
   float *render_buffer;
+  int offset;
+
+  /* Init kernel arguments */
+  int num_tiles;
+  int max_tile_work_size;
 
   /* Global scene data and textures */
   KernelData data;
@@ -33,10 +41,16 @@ struct KernelParamsOptiX {
 
   /* Integrator state */
   IntegratorStateGPU integrator_state;
+
+  void *osl_colorsystem;
 };
 
 #ifdef __NVCC__
-extern "C" static __constant__ KernelParamsOptiX kernel_params;
+extern "C"
+#  ifndef __CUDACC_RDC__
+    static
+#  endif
+    __constant__ KernelParamsOptiX kernel_params;
 #endif
 
 /* Abstraction macros */
