@@ -2,19 +2,21 @@
  *
  * SPDX-License-Identifier: Apache-2.0 */
 
-#ifndef __UTIL_IMAGE_H__
-#  define __UTIL_IMAGE_H__
+#pragma once
 
 /* OpenImageIO is used for all image file reading and writing. */
 
-#  include <OpenImageIO/imageio.h>
+#include <OpenImageIO/imageio.h>
 
-#  include "util/half.h"
-#  include "util/vector.h"
+#include "util/half.h"
+#include "util/vector.h"
 
 CCL_NAMESPACE_BEGIN
 
-OIIO_NAMESPACE_USING
+using OIIO::AutoStride;
+using OIIO::ImageInput;
+using OIIO::ImageOutput;
+using OIIO::ImageSpec;
 
 template<typename T>
 void util_image_resize_pixels(const vector<T> &input_pixels,
@@ -30,15 +32,15 @@ void util_image_resize_pixels(const vector<T> &input_pixels,
 /* Cast input pixel from unknown storage to float. */
 template<typename T> inline float util_image_cast_to_float(T value);
 
-template<> inline float util_image_cast_to_float(float value)
+template<> inline float util_image_cast_to_float(const float value)
 {
   return value;
 }
-template<> inline float util_image_cast_to_float(uchar value)
+template<> inline float util_image_cast_to_float(const uchar value)
 {
   return (float)value / 255.0f;
 }
-template<> inline float util_image_cast_to_float(uint16_t value)
+template<> inline float util_image_cast_to_float(const uint16_t value)
 {
   return (float)value / 65535.0f;
 }
@@ -48,33 +50,33 @@ template<> inline float util_image_cast_to_float(half value)
 }
 
 /* Cast float value to output pixel type. */
-template<typename T> inline T util_image_cast_from_float(float value);
+template<typename T> inline T util_image_cast_from_float(const float value);
 
-template<> inline float util_image_cast_from_float(float value)
+template<> inline float util_image_cast_from_float(const float value)
 {
   return value;
 }
-template<> inline uchar util_image_cast_from_float(float value)
+template<> inline uchar util_image_cast_from_float(const float value)
 {
   if (value < 0.0f) {
     return 0;
   }
-  else if (value > (1.0f - 0.5f / 255.0f)) {
+  if (value > (1.0f - 0.5f / 255.0f)) {
     return 255;
   }
-  return (uchar)((255.0f * value) + 0.5f);
+  return (uchar)((255.0f * value) + 0.5f);  // NOLINT
 }
-template<> inline uint16_t util_image_cast_from_float(float value)
+template<> inline uint16_t util_image_cast_from_float(const float value)
 {
   if (value < 0.0f) {
     return 0;
   }
-  else if (value > (1.0f - 0.5f / 65535.0f)) {
+  if (value > (1.0f - 0.5f / 65535.0f)) {
     return 65535;
   }
-  return (uint16_t)((65535.0f * value) + 0.5f);
+  return (uint16_t)((65535.0f * value) + 0.5f);  // NOLINT
 }
-template<> inline half util_image_cast_from_float(float value)
+template<> inline half util_image_cast_from_float(const float value)
 {
   return float_to_half_image(value);
 }
@@ -82,15 +84,15 @@ template<> inline half util_image_cast_from_float(float value)
 /* Multiply image pixels in native data format. */
 template<typename T> inline T util_image_multiply_native(T a, T b);
 
-template<> inline float util_image_multiply_native(float a, float b)
+template<> inline float util_image_multiply_native(const float a, const float b)
 {
   return a * b;
 }
-template<> inline uchar util_image_multiply_native(uchar a, uchar b)
+template<> inline uchar util_image_multiply_native(const uchar a, const uchar b)
 {
   return ((uint32_t)a * (uint32_t)b) / 255;
 }
-template<> inline uint16_t util_image_multiply_native(uint16_t a, uint16_t b)
+template<> inline uint16_t util_image_multiply_native(const uint16_t a, const uint16_t b)
 {
   return ((uint32_t)a * (uint32_t)b) / 65535;
 }
@@ -101,6 +103,4 @@ template<> inline half util_image_multiply_native(half a, half b)
 
 CCL_NAMESPACE_END
 
-#endif /* __UTIL_IMAGE_H__ */
-
-#include "util/image_impl.h"
+#include "util/image_impl.h"  // IWYU pragma: export
