@@ -10,10 +10,6 @@
 
 #include "../BPy_UnaryFunction0DDouble.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 ///////////////////////////////////////////////////////////////////////////////////////////
 
 extern PyTypeObject ZDiscontinuityF0D_Type;
@@ -27,7 +23,3 @@ typedef struct {
 } BPy_ZDiscontinuityF0D;
 
 ///////////////////////////////////////////////////////////////////////////////////////////
-
-#ifdef __cplusplus
-}
-#endif
