@@ -104,6 +104,7 @@ static void rna_Curves_curve_offset_data_begin(CollectionPropertyIterator *iter,
 {
   Curves *curves = rna_curves(ptr);
   rna_iterator_array_begin(iter,
+                           ptr,
                            curves->geometry.wrap().offsets_for_write().data(),
                            sizeof(int),
                            curves->geometry.curve_num + 1,
@@ -117,9 +118,8 @@ static bool rna_Curves_curve_offset_data_lookup_int(PointerRNA *ptr, int index,
   if (index < 0 || index >= curves->geometry.curve_num + 1) {
     return false;
   }
-  r_ptr->owner_id = &curves->id;
-  r_ptr->type = &RNA_IntAttributeValue;
-  r_ptr->data = &curves->geometry.wrap().offsets_for_write()[index];
+  rna_pointer_create_with_ancestors(
+      *ptr, &RNA_IntAttributeValue, &curves->geometry.wrap().offsets_for_write()[index], *r_ptr);
   return true;
 }
 
@@ -145,6 +145,7 @@ static void rna_Curves_curves_begin(CollectionPropertyIterator *iter, PointerRNA
 {
   Curves *curves = rna_curves(ptr);
   rna_iterator_array_begin(iter,
+                           ptr,
                            curves->geometry.wrap().offsets_for_write().data(),
                            sizeof(int),
                            curves->geometry.curve_num,
@@ -164,9 +165,8 @@ static bool rna_Curves_curves_lookup_int(PointerRNA *ptr, int index, PointerRNA
   if (index < 0 || index >= curves->geometry.curve_num) {
     return false;
   }
-  r_ptr->owner_id = &curves->id;
-  r_ptr->type = &RNA_CurveSlice;
-  r_ptr->data = &curves->geometry.wrap().offsets_for_write()[index];
+  rna_pointer_create_with_ancestors(
+      *ptr, &RNA_CurveSlice, &curves->geometry.wrap().offsets_for_write()[index], *r_ptr);
   return true;
 }
 
@@ -182,9 +182,10 @@ bool rna_Curves_position_data_lookup_int(PointerRNA *ptr, int index, PointerRNA
   if (index < 0 || index >= curves->geometry.point_num) {
     return false;
   }
-  r_ptr->owner_id = &curves->id;
-  r_ptr->type = &RNA_FloatVectorAttributeValue;
-  r_ptr->data = &get_curves_positions_for_write(*curves)[index];
+  rna_pointer_create_with_ancestors(*ptr,
+                                    &RNA_FloatVectorAttributeValue,
+                                    &get_curves_positions_for_write(*curves)[index],
+                                    *r_ptr);
   return true;
 }
 
@@ -192,6 +193,7 @@ static void rna_Curves_position_data_begin(CollectionPropertyIterator *iter, Poi
 {
   Curves *curves = rna_curves(ptr);
   rna_iterator_array_begin(iter,
+                           ptr,
                            get_curves_positions_for_write(*curves),
                            sizeof(float[3]),
                            curves->geometry.point_num,
@@ -248,9 +250,8 @@ bool rna_Curves_points_lookup_int(PointerRNA *ptr, int index, PointerRNA *r_ptr)
   if (index < 0 || index >= curves->geometry.point_num) {
     return false;
   }
-  r_ptr->owner_id = &curves->id;
-  r_ptr->type = &RNA_CurvePoint;
-  r_ptr->data = &get_curves_positions_for_write(*curves)[index];
+  rna_pointer_create_with_ancestors(
+      *ptr, &RNA_CurvePoint, &get_curves_positions_for_write(*curves)[index], *r_ptr);
   return true;
 }
 
@@ -290,7 +291,7 @@ static void rna_CurveSlice_points_begin(CollectionPropertyIterator *iter, Pointe
   const int size = rna_CurveSlice_points_length_get(ptr);
   float(*positions)[3] = get_curves_positions_for_write(*curves);
   float(*co)[3] = positions + offset;
-  rna_iterator_array_begin(iter, co, sizeof(float[3]), size, 0, nullptr);
+  rna_iterator_array_begin(iter, ptr, co, sizeof(float[3]), size, 0, nullptr);
 }
 
 static void rna_Curves_normals_begin(CollectionPropertyIterator *iter, PointerRNA *ptr)
@@ -298,7 +299,7 @@ static void rna_Curves_normals_begin(CollectionPropertyIterator *iter, PointerRN
   Curves *curves = rna_curves(ptr);
   float(*positions)[3] = blender::ed::curves::point_normals_array_create(curves);
   const int size = curves->geometry.point_num;
-  rna_iterator_array_begin(iter, positions, sizeof(float[3]), size, true, nullptr);
+  rna_iterator_array_begin(iter, ptr, positions, sizeof(float[3]), size, true, nullptr);
 }
 
 static void rna_Curves_update_data(Main * /*bmain*/, Scene * /*scene*/, PointerRNA *ptr)
@@ -511,6 +512,7 @@ static void rna_def_curves(BlenderRNA *brna)
   prop = RNA_def_property(srna, "surface", PROP_POINTER, PROP_NONE);
   RNA_def_property_struct_type(prop, "Object");
   RNA_def_property_flag(prop, PROP_EDITABLE);
+  RNA_def_property_override_flag(prop, PROPOVERRIDE_OVERRIDABLE_LIBRARY);
   RNA_def_property_pointer_funcs(prop, nullptr, nullptr, nullptr, "rna_Mesh_object_poll");
   RNA_def_property_ui_text(prop, "Surface", "Mesh object that the curves can be attached to");
   RNA_def_property_update(prop, NC_OBJECT | ND_DRAW, nullptr);
