@@ -30,7 +30,8 @@ static void node_declare(NodeDeclarationBuilder &b)
 {
   const bNode *node = b.node_or_null();
 
-  auto &first_grid = b.add_input<decl::Float>("Grid 1").hide_value();
+  auto &first_grid = b.add_input<decl::Float>("Grid 1").hide_value().structure_type(
+      StructureType::Grid);
 
   if (node) {
     static const auto make_available = [](bNode &node) {
@@ -42,16 +43,20 @@ static void node_declare(NodeDeclarationBuilder &b)
         b.add_input<decl::Float>("Grid", "Grid 2")
             .hide_value()
             .multi_input()
-            .make_available(make_available);
+            .make_available(make_available)
+            .structure_type(StructureType::Grid);
         break;
       case Operation::Difference:
-        b.add_input<decl::Float>("Grid 2").hide_value().multi_input().make_available(
-            make_available);
+        b.add_input<decl::Float>("Grid 2")
+            .hide_value()
+            .multi_input()
+            .make_available(make_available)
+            .structure_type(StructureType::Grid);
         break;
     }
   }
 
-  b.add_output<decl::Float>("Grid").hide_value();
+  b.add_output<decl::Float>("Grid").hide_value().structure_type(StructureType::Grid);
 
   if (node) {
     switch (Operation(node->custom1)) {
@@ -68,7 +73,7 @@ static void node_declare(NodeDeclarationBuilder &b)
 
 static void node_layout(uiLayout *layout, bContext * /*C*/, PointerRNA *ptr)
 {
-  uiItemR(layout, ptr, "operation", UI_ITEM_NONE, "", ICON_NONE);
+  layout->prop(ptr, "operation", UI_ITEM_NONE, "", ICON_NONE);
 }
 
 static void node_init(bNodeTree * /*tree*/, bNode *node)
@@ -188,7 +193,7 @@ static void node_register()
   ntype.draw_buttons = node_layout;
   ntype.geometry_node_execute = node_geo_exec;
   ntype.gather_link_search_ops = search_link_ops_for_volume_grid_node;
-  blender::bke::node_register_type(&ntype);
+  blender::bke::node_register_type(ntype);
   node_rna(ntype.rna_ext.srna);
 }
 NOD_REGISTER_NODE(node_register)
